@@ -7,7 +7,7 @@ rrdtool bindings, we'll need to provide pairs of strings for some
 of the parameters.
 '''
 
-def preparObject(obj):
+def prepareObject(obj):
     '''
     This is a funtion that serves to make interacting with the
     backend as transparent as possible. It's sole purpose it to
@@ -20,6 +20,6 @@ def preparObject(obj):
 
     This function will get called by methods in the pyrrd wrapper
     objects. For instance, most of the methods of pyrrd.rrd.RRD
-    will call this function. In graph, Pretty much only the method 
+    will call this function. In graph, Pretty much only the method
     pyrrd.graph.Graph.write() will call this function.
     '''
